# List of entities

This page lists entities records in a collection, and provides options for them to be created, copied, edited or deleted. Initially, the default behaviour is to display all entities defined in the current collection, but different list options may be selected from the 'List view' dropdown, and displayed contents may be filtered by entering a value in the 'Search' box. To refresh the display after making any such selections, click the 'View' button. To set the default list for the current collection to be the currently displayed list, click on the 'Set default' button at the bottom of the page.

To create a new entity record, click on the 'New' button. A new form will be presented allowing data values to be entered.

To copy or edit an entity record, click on the coprresponding checkbox on the right of the list, and then click 'Copy' or 'Edit'. A form will be presented allowing data values to be modified ort entered. To delete an enttiy record, click on the coprresponding checkbox on the right of the list, and then click 'delete'. Options to create, copy, edit and/or delete entity records are displayed only for logged-in users.

The 'Customize' button displays a new form that allows entity types, lists and/or views to be created, modified or deleted.